import http.client
import json

from payout.create_payout_account import CreatePayoutAccount
from payout.update_payout_account import UpdatePayoutAccount
from payout.find_payout_account import FindPayoutAccount
from payout.add_payout_token import AddPayoutToken
from payout.add_payout_rate import AddPayoutRate
from payout.start_payouts import StartPayouts
from payout.stop_payouts import StopPayouts


class Payout:
    def __init__(self, app, key) -> None:
        self.app = app
        self.key = key
        # Get app endpoints
        conn = http.client.HTTPSConnection("reddash.azurewebsites.net")
        route = "/app/endpoints/" + self.app
        headers = {"Accept": "application/json"}
        conn.request("POST", route, "", headers)
        response = json.loads(conn.getresponse().read().decode())
        # Parse and set dataEndpoints
        if "dataEndpoints" in response:
            self.dataEndpoints = response["dataEndpoints"]
        else:
            self.dataEndpoints = "ERROR Unable to get dataEndpoints from server"
        # Parse and set redpayEndpoints
        if "redpayEndpoints" in response:
            self.redpayEndpoints = response["redpayEndpoints"]
        else:
            self.redpayEndpoints = "ERROR Unable to get redpayEndpoints from server"

    def CreatePayoutAccount(self, request):
        request["app"] = self.app
        create_payout_account = CreatePayoutAccount(
            self.app, self.key, self.dataEndpoints)
        return create_payout_account.Process(request)

    def UpdatePayoutAccount(self, request):
        request["app"] = self.app
        update_payout_account = UpdatePayoutAccount(
            self.app, self.key, self.dataEndpoints)
        return update_payout_account.Process(request)

    def FindPayoutAccount(self, request):
        request["app"] = self.app
        find_payout_account = FindPayoutAccount(
            self.app, self.key, self.dataEndpoints)
        return find_payout_account.Process(request)

    def AddPayoutRate(self, request):
        request["app"] = self.app
        request["account"] = request["id"]
        add_payout_rate = AddPayoutRate(
            self.app, self.key, self.dataEndpoints)
        return add_payout_rate.Process(request)

    def AddPayoutToken(self, request):
        request["app"] = self.app
        request["account"] = request["id"]
        add_payout_token = AddPayoutToken(
            self.app, self.key, self.dataEndpoints)
        return add_payout_token.Process(request)

    def StartPayouts(self, request):
        request["app"] = self.app
        request["account"] = request["id"]
        start_payouts = StartPayouts(
            self.app, self.key, self.dataEndpoints)
        return start_payouts.Process(request)

    def StopPayouts(self, request):
        request["app"] = self.app
        request["account"] = request["id"]
        stop_payouts = StopPayouts(
            self.app, self.key, self.dataEndpoints)
        return stop_payouts.Process(request)



import http.client
import urllib.parse as urlparse
import json


class AddPayoutToken:
    def __init__(self, app, key, endpoint) -> None:
        self.app = app
        self.key = key
        self.endpoint = endpoint
        self.route = "/payouttoken/add"

    def Process(self, request):
        json_data = json.dumps(request)
        headers = {"Content-type": "application/json",
                   "Accept": "application/json"}

        url_info = urlparse.urlparse(self.endpoint)
        if url_info.scheme == "https":
            conn = http.client.HTTPSConnection(
                url_info.hostname, url_info.port or 443)
        else:
            conn = http.client.HTTPSConnection(
                url_info.hostname, url_info.port or 80)

        try:
            conn.request('POST', self.route, json_data, headers)
            response = conn.getresponse()
            if response.status == 200:
                return json.loads(response.read().decode())
            else:
                return {
                    "code": response.status,
                    "error": response.reason
                }
        finally:
            conn.close()



from payout.payout import Payout

from payout.create_payout_account import CreatePayoutAccount
from payout.update_payout_account import UpdatePayoutAccount
from payout.find_payout_account import FindPayoutAccount
from payout.add_payout_token import AddPayoutToken
from payout.add_payout_rate import AddPayoutRate
from payout.start_payouts import StartPayouts
from payout.stop_payouts import StopPayouts



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name='payout',
    version='1.1.2',
    packages=['payout'],
    url='https://bitbucket.org/redshepherdinc/python-payout-api.git',
    author='Red Shepherd Inc.',
    author_email='support@redshepherd.com',
    description='Python API for integrating with the Red Shepherd Payouts',
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Development Status :: 5 - Production/Stable',
        # Define that your audience are developers
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',   # Again, pick a license
        # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    python_requires='>=3.5'
)
